summaryrefslogtreecommitdiffstats
path: root/kjsembed/jsbindingplugin.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-05 15:55:57 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-05 15:55:57 -0600
commit9ba04742771370f59740e32e11c5f3a1e6a1b70a (patch)
treec81c34dae2b3b1ea73801bf18a960265dc4207f7 /kjsembed/jsbindingplugin.h
parent1a96c45b22d01378202d9dc7ed9c47acd30f966e (diff)
downloadtdebindings-9ba04742771370f59740e32e11c5f3a1e6a1b70a.tar.gz
tdebindings-9ba04742771370f59740e32e11c5f3a1e6a1b70a.zip
Initial TQt conversion
Diffstat (limited to 'kjsembed/jsbindingplugin.h')
-rw-r--r--kjsembed/jsbindingplugin.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kjsembed/jsbindingplugin.h b/kjsembed/jsbindingplugin.h
index fb7d6361..6d54a508 100644
--- a/kjsembed/jsbindingplugin.h
+++ b/kjsembed/jsbindingplugin.h
@@ -39,14 +39,14 @@ namespace KJSEmbed {
* @author Ian Reinhart Geiser, geiseri@kde.org
* @version $Id$
*/
- class KJSEMBED_EXPORT JSBindingPlugin : public TQObject {
+ class KJSEMBED_EXPORT JSBindingPlugin : public TTQObject {
Q_OBJECT
public:
- JSBindingPlugin( TQObject *parent, const char *name, const TQStringList &args );
+ JSBindingPlugin( TTQObject *parent, const char *name, const TTQStringList &args );
virtual ~JSBindingPlugin();
/**
* This method is called by the KJSFactory to bootstrap the plugin.
* Plugin developers will want to use this method to create their TQObject binding,
* or call their addBindings() method in their JSOpaque proxy or JSValueProxy.
*
* The value returned from ths function is the KJS::Object that represents the
@@ -39,14 +39,14 @@ namespace KJSEmbed {
/**
* This method is called by the KJSFactory to bootstrap the plugin.
- * Plugin developers will want to use this method to create their TQObject binding,
+ * Plugin developers will want to use this method to create their TTQObject binding,
* or call their addBindings() method in their JSOpaque proxy or JSValueProxy.
*